package com.evobms.project.bms.mapper;

import java.util.List;
import com.evobms.project.bms.domain.BmsRuntimeData;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * BMS实时运行数据Mapper接口
 * 
 * @author tzy
 * @date 2026-02-23
 */
public interface BmsRuntimeDataMapper extends BaseMapper<BmsRuntimeData> {
    /**
     * 查询BMS实时运行数据
     * 
     * @param id BMS实时运行数据主键
     * @return BMS实时运行数据
     */
    public BmsRuntimeData selectBmsRuntimeDataById(Long id);

    /**
     * 查询BMS实时运行数据列表
     * 
     * @param bmsRuntimeData BMS实时运行数据
     * @return BMS实时运行数据集合
     */
    public List<BmsRuntimeData> selectBmsRuntimeDataList(BmsRuntimeData bmsRuntimeData);

    /**
     * 新增BMS实时运行数据
     * 
     * @param bmsRuntimeData BMS实时运行数据
     * @return 结果
     */
    public int insertBmsRuntimeData(BmsRuntimeData bmsRuntimeData);

    /**
     * 修改BMS实时运行数据
     * 
     * @param bmsRuntimeData BMS实时运行数据
     * @return 结果
     */
    public int updateBmsRuntimeData(BmsRuntimeData bmsRuntimeData);

    /**
     * 删除BMS实时运行数据
     * 
     * @param id BMS实时运行数据主键
     * @return 结果
     */
    public int deleteBmsRuntimeDataById(Long id);

    /**
     * 批量删除BMS实时运行数据
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBmsRuntimeDataByIds(Long[] ids);
}
