package com.evobms.project.bms.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.evobms.framework.aspectj.lang.annotation.Log;
import com.evobms.framework.aspectj.lang.enums.BusinessType;
import com.evobms.project.bms.domain.BmsRuntimeData;
import com.evobms.project.bms.service.IBmsRuntimeDataService;
import com.evobms.framework.web.controller.BaseController;
import com.evobms.framework.web.domain.AjaxResult;
import com.evobms.common.utils.poi.ExcelUtil;
import com.evobms.framework.web.page.TableDataInfo;

/**
 * BMS实时运行数据Controller
 *
 * @author tzy
 * @date 2026-02-23
 */
@RestController
@RequestMapping("/bms/runtime/data")
public class BmsRuntimeDataController extends BaseController
{
    @Autowired
    private IBmsRuntimeDataService bmsRuntimeDataService;

    /**
     * 查询BMS实时运行数据列表
     */
    @PreAuthorize("@ss.hasPermi('bms:data:list')")
    @GetMapping("/list")
    public TableDataInfo list(BmsRuntimeData bmsRuntimeData)
    {
        startPage();
        List<BmsRuntimeData> list = bmsRuntimeDataService.selectBmsRuntimeDataList(bmsRuntimeData);
        return getDataTable(list);
    }

    /**
     * 导出BMS实时运行数据列表
     */
    @PreAuthorize("@ss.hasPermi('bms:data:export')")
    @Log(title = "BMS实时运行数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsRuntimeData bmsRuntimeData)
    {
        List<BmsRuntimeData> list = bmsRuntimeDataService.selectBmsRuntimeDataList(bmsRuntimeData);
        ExcelUtil<BmsRuntimeData> util = new ExcelUtil<BmsRuntimeData>(BmsRuntimeData.class);
        util.exportExcel(response, list, "BMS实时运行数据数据");
    }

    /**
     * 获取BMS实时运行数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('bms:data:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bmsRuntimeDataService.selectBmsRuntimeDataById(id));
    }

    /**
     * 新增BMS实时运行数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:add')")
    @Log(title = "BMS实时运行数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsRuntimeData bmsRuntimeData)
    {
        return toAjax(bmsRuntimeDataService.insertBmsRuntimeData(bmsRuntimeData));
    }

    /**
     * 修改BMS实时运行数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:edit')")
    @Log(title = "BMS实时运行数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsRuntimeData bmsRuntimeData)
    {
        return toAjax(bmsRuntimeDataService.updateBmsRuntimeData(bmsRuntimeData));
    }

    /**
     * 删除BMS实时运行数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:remove')")
    @Log(title = "BMS实时运行数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bmsRuntimeDataService.deleteBmsRuntimeDataByIds(ids));
    }
}
